# -*- coding: utf-8 -*-

import os
import sys

from paver.easy import task, consume_args

DISABLED_LIBS = []


@task
@consume_args
def pidmatsync(args):
    from pidmatsync.__main__ import main
    main(args)


def find_version(filename):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    with open(filepath, 'r') as init:
        for line in init:
            if line.startswith('__version__'):
                x, version = line.split('=', 1)
                return version.strip().strip('\'"')
        else:
            raise ValueError('Cannot find the version in {0}'.format(filename))


def parse_requirements(requirements_txt):
    requirements = []
    try:
        with open(requirements_txt, 'r') as f:
            for line in f:
                line = line.strip()
                if line.startswith('#') or not line:
                    continue
                if line.startswith('-'):
                    raise ValueError('Unexpected command {0} in {1}'.format(
                        line,
                        requirements_txt,
                    ))

                requirements.append(line)
        return requirements
    except IOError:
        return []


@task
def setup_options():
    import setuptools
    from paver.setuputils import setup
    readme_md = os.path.join(os.path.dirname(__file__), 'README.md')
    with open(readme_md, 'r') as readme_file:
        readme = readme_file.read()

    setup(
        name='pidmatsync',
        version=find_version('pidmatsync/__init__.py'),
        description='Matricule synchronization with PasteurID',
        long_description=readme,
        author='Grégoire ROCHER',
        author_email='gr@enix.org',
        packages=setuptools.find_packages(
            include=[
                'pidmatsync',
                'pidmatsync.*',
            ]
        ),
        scripts=[
            'bin/pidmatsync',
        ],
        include_package_data=True,
        install_requires=parse_requirements('requirements.txt'),
        zip_safe=False,
    )


if os.path.abspath(sys.argv[0]) == os.path.abspath(os.path.join(os.path.dirname(__file__), 'setup.py')):
    setup_options()

try:
    import sett
    with open(sett.ROOT.joinpath('localpavement.py'), 'r') as localpavement:
        exec(localpavement.read(), locals(), globals())
except (OSError, IOError, ImportError) as e:
    pass
