#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pidmatsync.sync import (Sync as SyncInstance, PersonSync, TeamSync,
                             DeptSync, CachedSync, MembershipSync, ApiSource,
                             MailSync, RateLimitedAPISource)
from pidmatsync.connection import RequestMaker, TokenAuthentication


__author__ = 'Grégoire ROCHER'
__email__ = 'gr@enix.org'
__version__ = '0.4.0'


def Sync(token, url='https://pasteurid.pasteur.fr/api/v1/'):
    auth = TokenAuthentication(token)
    rmaker = RequestMaker(auth, insecure_ssl=False)
    api_source = ApiSource(rmaker, url)
    api_source = RateLimitedAPISource(api_source)

    return SyncInstance(
        teams=CachedSync(TeamSync(api_source, CachedSync(DeptSync(api_source)))),
        persons=PersonSync(api_source, MailSync(api_source)),
        memberships=MembershipSync(api_source),
    )


def pidmatsync(values, token):
    s = Sync(token)
    for v in values:
        yield s(v)
