# -*- coding: utf-8 -*-

import logging
import requests

from requests.auth import AuthBase

logger = logging.getLogger(__name__)


class TokenAuthentication(AuthBase):

    def __init__(self, token):
        # setup any auth-related data here
        self.authorization_header = 'Token {}'.format(token)

    def __call__(self, r):
        # modify and return the request
        r.headers['Authorization'] = self.authorization_header
        return r


class RequestMaker(object):
    def __init__(self, auth=None, insecure_ssl=False):
        self.auth = auth
        self.verify_ssl = not insecure_ssl
        self.session = requests.Session()

    def __repr__(self):
        return '{}/{}'.format('anon' if self.auth is None else 'auth',
                              'SSL' if self.verify_ssl else 'SSL?')

    def __call__(self, method, url, data=None, **kw):
        logger.info('Request %s %s', method, url)
        try:
            resp = self.session.request(
                method, url,
                auth=self.auth,
                data=data,
                verify=self.verify_ssl,
                **kw
            )
        except requests.RequestException as e:
            logger.error('Request [%s] failed, %s', repr(data)[:20], e)
            return
        if not (200 <= resp.status_code < 400):
            logger.error('Request [%s] failed, %s', repr(data)[:20], resp)
            logger.warning('Failure was %s', resp.text[:1000])
        else:
            logger.debug('Resp %s', resp)
        return resp.json()
